{% load shop_tags i18n %}
<ul class="order-totals">
	{% if discount_total or shipping_total %}
	<li><label>{% trans "Sub total" %}:</label> {{ item_total|currency }}</li>
	{% endif %}
	{% if discount_total %}
	<li>
	    <label>
	    {% if discount_type %}
	    {{ discount_type }}
	    {% else %}
	    {% trans "Discount" %}
	    {% endif %}:
	    </label> - {{ discount_total|currency }}
	</li>
	{% endif %}
	{% if shipping_total %}
	<li>
	    <label>
	    {% if shipping_type %}
	    {{ shipping_type }}
	    {% else %}
	    {% trans "Shipping" %}
	    {% endif %}:
	    </label> {{ shipping_total|currency }}
	</li>
	{% endif %}
	<li><label>{% trans "Total" %}:</label> {{ order_total|currency }}</li>
</ul>

